/*
 * This script sets the properties of a set of layers. A config is a simple text entity
 * on the _DEFS layer (see PredefTools) with the following lines:
 *         layer
 *         MyName    <<config-name>>
 *         CFG1      <<1. configuration of a layer>>
 *         CFG2      <<2. configuration of a layer>>
 *         ...       >>add all configurations of layers<<
 * Each configuration contains a slash separated list of the name, the color, the lineweight and the linetype
 * of this layer (see ListLayerConfigs).
 *
 * Copyright smf, some ideas taken from the QCad example scripts
 * last change: 2012-04-06
 */

//http://www.ribbonsoft.com/doc/qcad/3.0/developer/class_r_entity.html

include("../MyTools.js");
include("../PredefTools.js");

function ActivateLayerConfig(guiAction) {
    MyTools.call(this, guiAction);
}

ActivateLayerConfig.prototype = new EAction();
ActivateLayerConfig.includeBasePath = includeBasePath;

ActivateLayerConfig.prototype.beginEvent = function() {
    EAction.prototype.beginEvent.call(this);
    var document = EAction.getDocument();
    var di = EAction.getDocumentInterface();

    //get predef configurations and let the user select the desired one
    var layerConfigs = new Array();
    getAllPredefs(document, null, null, layerConfigs);
    if (layerConfigs.length<1) {
        EAction.handleUserMessage("predef layer not found or no valid text entities on it");
        this.terminate();
        return;
    }
    var dialog = WidgetFactory.createWidget(
                   "scripts/MyTools",
                   "PredefSelectDialog.ui");
    var widgets = getWidgets(dialog);
    var list = widgets["list"];
    list.itemDoubleClicked.connect(dialog, "accept");
    for (var pd = 0; pd < layerConfigs.length; pd++) {
        list.addItem(layerConfigs[pd][0]);
    }
    list.setCurrentItem(list.item(0));
    if (!dialog.exec()) {
        this.terminate();
        return;
    }

    //activate the configuration
    var configList = layerConfigs[list.currentRow];
    EAction.handleUserMessage("activate layer config " + configList[0]);
    restoreLayerConfiguration(document, di, configList[1]);
    this.terminate();
};

ActivateLayerConfig.init = function(basePath) {
    var action = new RGuiAction("ActivateLayerConfi&g", RMainWindowQt.getMainWindow());
    action.setRequiresDocument(true);
    action.setScriptFile(basePath + "/ActivateLayerConfig.js");
    action.setSortOrder(200);
    EAction.addGuiActionTo(action, MyTools, true, false, false);
};
