/*
 * This script activates a predefined set of layers. A predef is a simple text entity
 * on the _DEFS layer (see PredefTools) with the following lines:
 *         MyName    <<predef-name>>
 *         CELA1     <<name 1 of layer to be active (non-frozen)>>
 *         CELA2     <<name 2 of layer to be active (non-frozen)>>
 *         ...       >>add all names of layers to be active<<
 *
 * Copyright smf, some ideas taken from the QCad example scripts
 * last change: 2012-04-06
 */

//http://www.ribbonsoft.com/doc/qcad/3.0/developer/class_r_entity.html

include("../MyTools.js");
include("../PredefTools.js");

function ActivatePredef(guiAction) {
    MyTools.call(this, guiAction);
}

ActivatePredef.prototype = new EAction();
ActivatePredef.includeBasePath = includeBasePath;

ActivatePredef.prototype.beginEvent = function() {
    EAction.prototype.beginEvent.call(this);
    var document = EAction.getDocument();
    var di = EAction.getDocumentInterface();

    //get predef configurations and let the user select the desired one
    var predefs = new Array();
    getAllPredefs(document, predefs, null, null);
    if (predefs.length<1) {
        EAction.handleUserMessage("predef layer not found or no text entities on it");
        this.terminate();
        return;
    }
    var dialog = WidgetFactory.createWidget(
                   "scripts/MyTools",
                   "PredefSelectDialog.ui");
    var widgets = getWidgets(dialog);
    var list = widgets["list"];
    list.itemDoubleClicked.connect(dialog, "accept");
    for (var pd = 0; pd < predefs.length; pd++) {
        list.addItem(predefs[pd][0]);
    }
    list.setCurrentItem(list.item(0));
    if (!dialog.exec()) {
        this.terminate();
        return;
    }

    //activate the configuration
    EAction.handleUserMessage("activate predef " + predefs[list.currentRow][0]);
    activatePredefLayers(document, di, predefs[list.currentRow][1]);
    this.terminate();
};

ActivatePredef.init = function(basePath) {
    var action = new RGuiAction("&ActivatePredef", RMainWindowQt.getMainWindow());
    action.setRequiresDocument(true);
    action.setScriptFile(basePath + "/ActivatePredef.js");
    action.setSortOrder(100);
    EAction.addGuiActionTo(action, MyTools, true, false, false);
};
