/*
 * This script searches the current selection for duplicates
 * and removes all duplicate lines.
 *
 * Copyright smf, some ideas taken from the QCad example scripts
 * last change: 2014-12-13
 */

include("../MyTools.js");

function DupRemover(guiAction) {
    MyTools.call(this, guiAction);
}

DupRemover.prototype = new EAction();
DupRemover.includeBasePath = includeBasePath;

DupRemover.prototype.beginEvent = function() {
    EAction.prototype.beginEvent.call(this);
    
    var doc = this.getDocument();
    var di = this.getDocumentInterface();
    var op = new RMixedOperation();
    var selected = doc.querySelectedEntities();
    
    var i, j, ent, cmp, estart, eend, cstart, cend, cnt = 0;
    for (i = 0; i < selected.length; i++) {
        ent = doc.queryEntity(selected[i]);
        if (ent !== null && ent.getType() !== RS.EntityLine) {
            selected[i] = null;
        }
    }
    for (i = 0; i < selected.length; i++) {
        if (selected[i] === null) continue;
        ent = doc.queryEntity(selected[i]);
        estart = ent.getStartPoint();
        eend = ent.getEndPoint();
        for (j = i + 1; j < selected.length; j++) {
            if (selected[j] === null) continue;
            cmp = doc.queryEntity(selected[j]);
            cstart = cmp.getStartPoint();
            cend = cmp.getEndPoint();
            if ((estart.getDistanceTo(cstart)<1 && eend.getDistanceTo(cend)<1)
                    || (estart.getDistanceTo(cend)<1 && eend.getDistanceTo(cstart)<1)) {
                break;
            }
        }
        if (j < selected.length) {
            op.deleteObject(ent);
            cnt++;
        }
    }
    di.applyOperation(op);
    EAction.handleUserMessage("deleted " + cnt + " lines");
    this.terminate();
};

DupRemover.init = function(basePath) {
    var action = new RGuiAction(qsTr("&DupRemover"), 
        RMainWindowQt.getMainWindow());
    action.setRequiresDocument(true);
    action.setRequiresSelection(true);
    action.setScriptFile(basePath + "/DupRemover.js");
    action.setSortOrder(600);
    EAction.addGuiActionTo(action, MyTools, true, false, false);
    var appWin = EAction.getMainWindow();
    appWin.addSelectionListener(action);
};
