/*
 * This script exports each layer to a PNG bitmap file
 *
 * Copyright smf, using QCad script BitmapExport
 * last change: 2018-11-09
 */

include("../MyTools.js");
include("scripts/File/File.js");
include("scripts/File/BitmapExport/BitmapExport.js");
include("scripts/File/BitmapExport/BitmapExportWorker.js");

function ExportLayerPNG(guiAction) {
    BitmapExport.call(this, guiAction);
}

ExportLayerPNG.prototype = new BitmapExport();

ExportLayerPNG.includeBasePath = includeBasePath;

ExportLayerPNG.prototype.beginEvent = function() {
    var properties = this.getProperties();
    if (isNull(properties)) {
        this.terminate();
        return;
    }

    var appWin = EAction.getMainWindow();
    var document = this.getDocument();
    var di = EAction.getDocumentInterface();
    var drawingFileName = document.getFileName();
    var initialPath = "";
    var fi;
    if (drawingFileName.length === 0) {
        fi = new QFileInfo(QDir.homePath());
        initialPath = fi.absoluteFilePath() + QDir.separator
                + stripDirtyFlag(EAction.getMdiChild().windowTitle);
    } else {
        fi = new QFileInfo(drawingFileName);
        initialPath = fi.path() + QDir.separator + fi.completeBaseName();
    }

    var layers = document.queryAllLayers();
    for (var lc = 0; lc < layers.length; lc++) {
        var operation = new RModifyObjectsOperation();
        for (var l = 0; l < layers.length; ++l) {
            var layer = document.queryLayer(layers[l]);
            layer.setFrozen(lc != l);
            operation.addObject(layer);
        }
        di.applyOperation(operation);
        di.updateAllEntities();
        di.clearPreview();
        di.repaintViews();

        var bmpFileName = initialPath + "_" + document.queryLayer(layers[lc]).getName() + ".png";
        var res = this.exportBitmap(this.getDocumentInterface(), bmpFileName, properties);
        if (!res[0]) {
            print("Error: cannot save file: ", bmpFileName);
            print("Error: ", res[1]);
            appWin.handleUserWarning(
                    qsTr("Error while generating Bitmap file '%1': %2")
                        .arg(bmpFileName).arg(res[1]));
            appWin.handleUserWarning();
            break;
        }
        else {
            appWin.handleUserMessage(
                    qsTr("Bitmap file has been exported to '%1'").arg(bmpFileName));
        }
    }

    var operation = new RModifyObjectsOperation();
    for (var l = 0; l < layers.length; ++l) {
        var layer = document.queryLayer(layers[l]);
        layer.setFrozen(false);
        operation.addObject(layer);
    }
    di.applyOperation(operation);
    di.updateAllEntities();
    di.clearPreview();
    di.repaintViews();

    EAction.handleUserMessage("Export done");

    this.terminate();
};

ExportLayerPNG.init = function(basePath) {
    var action = new RGuiAction("Layer &PNG Export...", RMainWindowQt.getMainWindow());
    action.setRequiresDocument(true);
    action.setScriptFile(basePath + "/ExportLayerPNG.js");
    EAction.addGuiActionTo(action, MyTools, true, false, false);
}

