/*
 * This script simply lists all currently active (non-frozen) layers.
 *
 * Copyright smf, some ideas taken from the QCad example scripts
 * last change: 2012-04-06
 *
 * layer attributes
 *   LAYERNAME
 *   COLOR
 *   LINEWEIGHT
 *   LINETYPE
 */

//http://www.ribbonsoft.com/doc/qcad/3.0/developer/class_r_entity.html

include("../MyTools.js");
include("../PredefTools.js");

function ListLayerConfigs(guiAction) {
    MyTools.call(this, guiAction);
}

ListLayerConfigs.prototype = new EAction();
ListLayerConfigs.includeBasePath = includeBasePath;

ListLayerConfigs.prototype.beginEvent = function() {
    EAction.prototype.beginEvent.call(this);
    var document = EAction.getDocument();
    var layers = getAllLayers(document);
    EAction.handleUserMessage("--- current layer configurations:");
    for (var lc = 0; lc < layers.length; lc++) {
        var layer = document.queryLayer(document.getLayerId(layers[lc]));
        //name
        var layerName = layers[lc];
        //color
        var color = layer.getColor();
        var colorName = color.getName();
        if (colorName === "#RRGGBB") {
            colorName=color.getRgb();
        }
        //lineweight
        var lwName = RLineweight.getName(layer.getLineweight());
        //linetype
        var ltName = document.queryLinetype(layer.getLinetypeId()).data().getName();
        //print it all together
        EAction.handleUserMessage(layerName + "/" + colorName + "/" + lwName + "/" + ltName);
    }
    EAction.handleUserMessage("--- done");
    this.terminate();
};

ListLayerConfigs.init = function(basePath) {
    var action = new RGuiAction("ListActiveLayer&Configs", RMainWindowQt.getMainWindow());
    action.setRequiresDocument(true);
    action.setScriptFile(basePath + "/ListLayerConfigs.js");
    action.setSortOrder(500);
    EAction.addGuiActionTo(action, MyTools, true, false, false);
};
