/*
 * This script prints the currently activated (non-frozen) layers as single page
 * as it would be printed by MultiPrintToPdf with according print config.
 *
 * Copyright smf, some ideas taken from the QCad example scripts
 * last change: 2018-11-09
 */

//http://www.ribbonsoft.com/doc/qcad/3.0/developer/class_r_entity.html

include("../MyTools.js");
include("../PredefTools.js");
include("scripts/File/Print/Print.js");

function QuickPrintToPdf(guiAction) {
    MyTools.call(this, guiAction);
}

QuickPrintToPdf.prototype = new EAction();
QuickPrintToPdf.includeBasePath = includeBasePath;

QuickPrintToPdf.prototype.beginEvent = function() {
    EAction.prototype.beginEvent.call(this);
    var document = EAction.getDocument();
    var di = EAction.getDocumentInterface();

    //get the center layer, scale and page size from user
    var dialog = WidgetFactory.createWidget(
                   "scripts/MyTools/QuickPrintToPdf",
                   "QPTPDialog.ui");
    var widgets = getWidgets(dialog);
    var list = widgets["list"];
    list.itemDoubleClicked.connect(dialog, "accept");
    var layerNames = getAllLayers(document);
    for (var lc = 0; lc < layerNames.length; lc++) {
        list.addItem(layerNames[lc]);
    }
    list.setCurrentItem(list.item(0));
    if (!dialog.exec()) {
        this.terminate();
        return;
    }
    var scale = widgets["editScale"].text;
    var width = widgets["editWidth"].text;
    var height = widgets["editHeight"].text;
    var centerLayerName = layerNames[list.currentRow];

    //inform the user about the configuration, perhaps he wants to add one to the _DEFS layer for later use with MultiPrintToPdf
    EAction.handleUserMessage("----- print config text is");
    EAction.handleUserMessage("print");
    EAction.handleUserMessage("<<PRINT-NAME");
    EAction.handleUserMessage(width);
    EAction.handleUserMessage(height);
    EAction.handleUserMessage("");
    EAction.handleUserMessage(scale);
    EAction.handleUserMessage(centerLayerName);
    EAction.handleUserMessage("<<PREDEF-NAME");
    EAction.handleUserMessage("----- end of print config");
    EAction.handleUserMessage("----- predef config text is");
    EAction.handleUserMessage("<<PREDEF-NAME");
    var activeLayerNames = getActiveLayers(document);
    for (var lc = 0; lc < activeLayerNames.length; lc++) {
        EAction.handleUserMessage(activeLayerNames[lc]);
    }
    EAction.handleUserMessage("----- end of predef config");

    //get the target file name from user
    var appWin = EAction.getMainWindow();
    var fileInfo = new QFileInfo(EAction.getDocument().getFileName());
    var filters = [ "PDF File (*.pdf)" ];
    var ret = File.getSaveFileName(appWin, qsTr("Multi-Export to PDF"),
                   fileInfo.absoluteFilePath(), filters);
    if (isNull(ret)) {
        this.terminate();
        return;
    }
    var pdfFile = ret[0];
    EAction.handleUserMessage("exporting to " + pdfFile);

    //prepare printing
    var mdiChild = EAction.getMdiChild();
    var view = mdiChild.getLastKnownViewWithFocus();
    var printer = new QPrinter(QPrinter.HighResolution);
    printer.setOutputFormat(QPrinter.PdfFormat);
    printer.setOutputFileName(pdfFile);
    printer.setPaperSize(new QSizeF(width, height));
    printer.setFullPage(true);
    printer.setOrientation(width > height ? QPrinter.Landscape : QPrinter.Portrait);
    printer.setColorMode(QPrinter.Color);
    var bgColor = view.getBackgroundColor();
    view.setBackgroundColor(new RColor("white"));
    view.setPrinting(true);
    var painter = new QPainter();
    painter.begin(printer);
    var unitScale = Print.getUnitScale(document);
    var widthInMM = printer.paperRect(QPrinter.Millimeter).width();
    var heightInMM = printer.paperRect(QPrinter.Millimeter).height();
    var paperBorder = new QRectF(0, 0, widthInMM, heightInMM);

    //print a single page without layer changes
    printSinglePage(document, di, view, centerLayerName, printer, painter, paperBorder, unitScale, scale, width, height);

    //finish printing
    painter.end();
    printer.destroy();
    view.setBackgroundColor(bgColor);
    view.setPrinting(false);
    EAction.handleUserMessage("export done");
    this.terminate();
};

QuickPrintToPdf.init = function(basePath) {
    var action = new RGuiAction("&QuickPrintToPdf", RMainWindowQt.getMainWindow());
    action.setRequiresDocument(true);
    action.setScriptFile(basePath + "/QuickPrintToPdf.js");
    action.setSortOrder(300);
    EAction.addGuiActionTo(action, MyTools, true, false, false);
};
